@@ -3,11 +3,15 @@ use Mojolicious::Lite -signatures;
 
 use Data::Dumper::Compact qw(ddc);
 use Mojo::JSON qw(to_json);
+use Mojo::File ();
 use Mojo::Util qw(trim);
+use Storable qw(store retrieve);
 
 use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(Synth-Config);
 use Synth::Config ();
 
+use constant SETTINGS => './eg/public/settings/';
+
 get '/' => sub ($c) {
   my $model  = $c->param('model');
   my $name   = $c->param('name');
@@ -20,8 +24,8 @@ get '/' => sub ($c) {
   my $synth = Synth::Config->new(model => $model, verbose => 1);
   if ($model) {
     # get a specs config file for the synth model
-    my $set = './eg/' . $synth->model . '.set';
-    my $specs = -e $set ? do $set : undef;
+    my $set_file = SETTINGS . $synth->model . '.dat';
+    my $specs = -e $set_file ? retrieve($set_file) : undef;
     # get the known groups if there are specs
     $groups = $specs ? $specs->{group} : undef;
     $groups = [ sort @$groups ] if $groups;
@@ -33,8 +37,8 @@ get '/' => sub ($c) {
       if ($fields) {
         my @fields = split /\s*,\s*/, $fields;
         for my $f (@fields) {
-          my ($x, $y) = split /\s*:\s*/, $f;
-          $parameters{$x} = $y;
+          my ($key, $val) = split /\s*:\s*/, $f;
+          $parameters{$key} = $val;
         }
       }
       $settings = $synth->search_settings(%parameters);
@@ -61,14 +65,78 @@ get '/' => sub ($c) {
   );
 } => 'index';
 
+get '/model' => sub ($c) {
+  my $model  = $c->param('model');
+  my $groups = $c->param('groups');
+  my $group_list = $groups ? [ split /\s*,\s*/, $groups ] : undef;
+  $c->render(
+    template   => 'model',
+    model      => $model,
+    groups     => $groups,
+    group_list => $group_list,
+  );
+} => 'model';
+post '/new_model' => sub ($c) {
+  my $v = $c->validation;
+  $v->required('model');
+  $v->required('groups');
+  if ($v->failed->@*) {
+    $c->flash(error => 'Could not add model');
+    return $c->redirect_to('model');
+  }
+  my $synth = Synth::Config->new(model => $v->param('model'));
+  my $group_params = $c->every_param('group');
+  if (@$group_params) {
+    my $model_file = SETTINGS . $synth->model . '.dat';
+    my @groups = split /\s*,\s*/, $v->param('groups');
+    my $specs = -e $model_file ? retrieve($model_file) : undef;
+    my $i = 0;
+    for my $g (@groups) {
+      $specs->{parameter}{$g} = [ split /\s*,\s*/, $group_params->[$i] ];
+      $i++;
+    }
+    store($specs, $model_file);
+    $c->flash(message => 'Add parameters successful');
+    return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
+  }
+  else {
+    my $init_file = Mojo::File->new(SETTINGS . 'initial.set');
+    my $specs = -e $init_file ? do $init_file : undef;
+    unless ($specs) {
+      $c->flash(error => 'Invalid init file');
+      return $c->redirect_to('model');
+    }
+    $specs->{group} = [ split /\s*,\s*/, $v->param('groups') ];
+    $specs->{parameter}{$_} = [] for $specs->{group}->@*; # TODO handle population
+    my $model_file = SETTINGS . $synth->model . '.dat';
+    store($specs, $model_file);
+    $c->flash(message => 'Add model successful');
+    return $c->redirect_to($c->url_for('model')->query(model => $v->param('model'), groups => $v->param('groups')));
+  }
+} => 'new_model';
+
 get '/remove' => sub ($c) {
-  my $id    = $c->param('id');
-  my $name  = $c->param('name');
-  my $model = $c->param('model');
-  my $synth = Synth::Config->new(model => $model);
-  $synth->remove_setting(id => $id);
-  $c->flash(message => 'Delete successful');
-  return $c->redirect_to($c->url_for('index')->query(model => $model, name => $name));
+  my $v = $c->validation;
+  $v->optional('id');
+  $v->optional('name');
+  $v->optional('model');
+  if ($v->failed->@*) {
+    $c->flash(error => 'Remove failed');
+    return $c->redirect_to('index');
+  }
+  my $synth = Synth::Config->new(model => $v->param('model'));
+  if ($v->param('id')) {
+    $synth->remove_setting(id => $v->param('id'));
+    $c->flash(message => 'Remove successful');
+    return $c->redirect_to($c->url_for('index')->query(model => $v->param('model'), name => $v->param('name')));
+  }
+  elsif ($synth->model) {
+    $synth->remove_model;
+    my $model_file = Mojo::File->new(SETTINGS . $synth->model . '.dat');
+    $model_file->remove;
+    $c->flash(message => 'Remove successful');
+    return $c->redirect_to('index');
+  }
 } => 'remove';
 
 get '/edit' => sub ($c) {
@@ -86,11 +154,11 @@ get '/edit' => sub ($c) {
   my $unit       = $c->param('unit');
   my $is_default = $c->param('is_default');
   $model = trim($model) if $model;
-  $name = trim($name) if $name;
+  $name  = trim($name)  if $name;
   my $synth = Synth::Config->new(model => $model);
   # get a specs config file for the synth model
-  my $set = './eg/' . $synth->model . '.set';
-  my $specs = -e $set ? do $set : undef;
+  my $set_file = SETTINGS . $synth->model . '.dat';
+  my $specs = -e $set_file ? retrieve($set_file) : undef;
   unless ($specs) {
     $c->flash(error => 'No known model');
     return $c->redirect_to('index');
@@ -141,8 +209,8 @@ post '/update' => sub ($c) {
   my $value = trim $v->param('value') if $v->param('value');
   my $synth = Synth::Config->new(model => $model);
   # get a specs config file for the synth model
-  my $set = './eg/' . $synth->model . '.set';
-  my $specs = -e $set ? do $set : undef;
+  my $set_file = SETTINGS . $synth->model . '.dat';
+  my $specs = -e $set_file ? retrieve($set_file) : undef;
   my $id = $synth->make_setting(
     id         => $v->param('id'),
     name       => $name,
@@ -195,7 +263,7 @@ __DATA__
     <select name="model" id="model" class="form-select" required>
       <option value="">Model name...</option>
 % for my $m (@$models) {
-      <option value="<%= $m %>" <%= $models && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
+      <option value="<%= $m %>" <%= $models && $model && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
 % }
     </select>
   </div>
@@ -226,7 +294,13 @@ __DATA__
 <div class="row">
   <div class="col">
     <button type="submit" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
+% if ($model) {
     <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+% }
+    <a href="<%= url_for('model') %>" class="btn btn-success"><i class="fa-solid fa-database"></i> New model</a>
+% if ($model) {
+    <a href="<%= url_for('remove')->query(model => $model) %>" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
+% }
   </div>
 </div>
 </form>
@@ -265,6 +339,46 @@ __DATA__
 % }
 
 
+@@ model.html.ep
+% layout 'default';
+% title 'Synth::Config';
+<p></p>
+<form action="<%= url_for('new_model') %>" method="post">
+<div class="row">
+  <div class="col">
+    <input type="text" name="model" id="model" value="<%= $model %>" class="form-control" placeholder="Model name" required>
+  </div>
+</div>
+<p></p>
+<div class="row">
+  <div class="col">
+    <input type="text" name="groups" id="groups" value="<%= $groups %>" class="form-control" placeholder="group1, group2, etc." required>
+  </div>
+</div>
+<p></p>
+<div class="row">
+  <div class="col">
+% unless ($group_list) {
+    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add Model</button>
+% }
+    <a href="<%= url_for('index') %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
+  </div>
+</div>
+</form>
+% if ($group_list) {
+<p></p>
+<form action="<%= url_for('new_model') %>" method="post">
+  <input type="hidden" name="model" value="<%= $model %>">
+  <input type="hidden" name="groups" value="<%= $groups %>">
+%   for my $g (@$group_list) {
+  <input type="text" name="group" id="<%= $g %>" class="form-control" placeholder="<%= ucfirst $g %> parameter1, param2, etc.">
+  <p></p>
+%   }
+  <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add parameters</button>
+</form>
+% }
+
+
 @@ edit.html.ep
 % layout 'default';
 % title 'Synth::Config';
@@ -326,20 +440,22 @@ __DATA__
 </div>
   <p></p>
   <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
+% if ($id) {
   <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
+% }
   <a href="<%= url_for('index')->query(model => $model, name => $name, group => $selected->{group}) %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
 </form>
-
 <script>
 $(document).ready(function() {
   function populate (group, param) {
+    const paramUcfirst = param.charAt(0).toUpperCase() + param.substring(1) + '...';
     const selected = $("select#" + group).find(":selected").val();
     const dropdown = $("select#" + param);
     const json = '<%= to_json $specs->{parameter} %>'.replace(/&quot;/g, '"');
     const params = JSON.parse(json);
     const obj = params[selected];
     dropdown.empty();
-    dropdown.append($('<option></option>').val("").text('Select...'));
+    dropdown.append($('<option></option>').val("").text(paramUcfirst));
     obj.forEach((i) => {
       let text = i.replace(/-/g, ' ');
       text = text.charAt(0).toUpperCase() + text.substring(1);
