@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0026';
+our $VERSION = '0.0027';
 
 use Moo;
 use strictures 2;
@@ -201,9 +201,7 @@ sub remove_settings {
 
 
 sub remove_model {
-  my ($self, %args) = @_;
-  my $model = delete $args{model};
-  croak 'No model given' unless $model;
+  my ($self) = @_;
   $self->_sqlite->query(
     'drop table ' . $self->model
   );
@@ -223,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0026
+version 0.0027
 
 =head1 SYNOPSIS
 
@@ -371,9 +369,9 @@ Remove all settings for a given B<name>.
 
 =head2 remove_model
 
-  $synth->remove_model(model => $model);
+  $synth->remove_model;
 
-Remove the database table for a given B<model>.
+Remove the database table for the object model.
 
 =head1 SEE ALSO
 
